#[non_exhaustive]pub struct SecretEncryptedData;Expand description
Encrypted data for a secret storage encryption algorithm.
This type cannot be constructed, it is only used for its semantic value and is meant to be used
with the Raw::cast() and Raw::deserialize_as() APIs.
It can be cast to or from the following types:
Convenience methods are also available for casting encrypted data from or to known compatible types.
Implementations
Sourceimpl SecretEncryptedData
impl SecretEncryptedData
Sourcepub fn new<T: JsonCastable<Self>>(encrypted_data: Raw<T>) -> Raw<Self>
pub fn new<T: JsonCastable<Self>>(encrypted_data: Raw<T>) -> Raw<Self>
Construct a Raw<SecretEncryptedData> by casting the given serialized encrypted data.
Sourcepub fn serialize<T: Serialize + JsonCastable<Self>>(
encrypted_data: &T,
) -> Result<Raw<Self>, Error>
pub fn serialize<T: Serialize + JsonCastable<Self>>( encrypted_data: &T, ) -> Result<Raw<Self>, Error>
Serialize the given encrypted data as a Raw<SecretEncryptedData>.
Sourcepub fn deserialize_as_aes_hmac_sha2(
encrypted_data: &Raw<Self>,
) -> Result<AesHmacSha2EncryptedData, Error>
pub fn deserialize_as_aes_hmac_sha2( encrypted_data: &Raw<Self>, ) -> Result<AesHmacSha2EncryptedData, Error>
Deserialize the given data encrypted with the m.secret_storage.v1.aes-hmac-sha2 algorithm.